.TH mrolo L "19 April 1993"
.SH NAME
mrolo \- Motif-based card file manager
.SH SYNOPSIS
.B mrolo
[
.B X11-options
] [
.B -vhs
] [
.B -f filename
]
.SH DESCRIPTION
.LP
.I MRolo
is a program for maintaining a simple card-file,
specifically oriented for saving address-book
information.
.LP
The default database file read is
.IR $HOME/.rolo ,
although this can be overridden with the
.B ROLODEX
environment variable or the
.B -f
command-line argument.
If the file does not exist, it is created empty.
The database is stored in a format similar to that of the
.I xrolo
program:  Blocks of text separated by lines containing just
a ctrl-L.  In addition,
.I MRolo
assumes that the first line in a block is the primary name,
the second line is the primary number, the third line
is a secondary number, and the rest is for other names,
numbers, and comments.  (You don't need
to understand the file format to use
.IR MRolo .)
.LP
When invoked
.I MRolo
will present the user with a screen summarizing the database.
The user may scroll through the summary with the scroll-bar,
or they may click on one of the large letters along the left
edge of the window and jump right to that part of the database.
Selecting an individual summary entry
will display a window containing the full information of
that entry, ready for editing or viewing.
.LP
On the main
.I MRolo
screen there are three buttons and a text field.
The three buttons are as follows:
.TP 2
.B Quit
Exit the
.I MRolo
program immediately.
.TP 2
.B "Add Card"
Display a blank detail window, into which new card information
may be entered.
.TP 2
.B "Clear Filter"
Clear the selection filter, as described in the next paragraph.
.LP
Typing some text in the text field and pressing
.I return
will limit the summary display to only those cards which contain
that text somewhere in their entry (the entire entry,
not just the summary).  All of the cards are still in the database,
they just aren't all accessible.  To see all of the cards again,
delete all the text from the text field and press
.I return
or just press the
.B "Clear Filter"
button.  Usually, this text is matched as simple, case-insensitive
text, but if the first letter in the filter text is a back-slash
then the rest of the text is interpreted as a regular expression.
.LP
Any time you change a card, add a new card, or delete a card
(by pressing "Delete Card" on the detail screen), you will
be asked before the data is written to the disk.  You never
have to explicitly save the database, it is done by validating
the individual changes.  Likewise the screen always reflects
the current contents of the database, except when a filter has
been applied thus hiding some of the database from view.
.LP
There are companion programs included in this package but
documented separately.  They are:
.IP "\fIcrolo\fR"
curses-based card file database manager
.IP "\fIprolo\fR"
prints card file databases in postscript
.IP "\fIxr2mr\fR"
converts xrolodex files to crolo format
.SH OPTIONS
.TP
.B \-v
Display the version number and show error messages.
.TP
.B \-s
Include a field selection menu, to allow restriction
of filter searches to certain fields.
.TP
.B \-f filename
Run using the specified file as the default database.
.SH ADVANCED TECHNIQUES
.LP
If you start a line in the comment section of your
card entry with the phrase "as of:" (note that the space
and the colon are important) then mrolo will put the
current date in the format of ctime(3) after the colon
whenever the field is changed.  This keeps track of how
current the card is.
.LP
If you like using
.I mrolo
then there are some "advanced" techniques you might
want to know about.  These tricks allow you to
get more power and flexibility out of the simple
.I mrolo
interface.
.LP
Remember that everything is optional and the program doesn't
care what is where.  You can put text in the slots traditionally
used for phone numbers, so if there is no secondary number some
additional descriptive text can go there.
.LP
While the program was developed for an address book, exploit
it for whatever you need, for example record or video collection
databases would work well.
.LP
You can simulate having several address books by including codes
in the comment section of the cards.  For example, I use
the code "~p" for personal entries, and "~w" for work
related entries.
If I want to see just work entries I can
enter "~w" in the filter.
Note that cards can appear in multiple lists by including
all applicable codes:  for example, Karen's entry has a "~p~w"
code since she is my friend and I work with her.
.LP
People who use
.I mrolo
a lot will want to know about
.IR prolo ,
which is used for printing card file databases.  Once you
know how this program works (see the manpage for
.IR prolo )
you can optimize your entries to look better on paper.
.SH XDEFAULTS
.LP
There are a number of values you may wish to tweek in your
X-Defaults.  Look at the app defaults file for a more complete
list than is given here.
.TP
mrolo*showSecondary
If set to True (the default) the main screen will
show both primary and secondary numbers, if False
only the primary number will be shown.  This does
not affect the card screen or the file format.
.TP
mrolo*sizePrimary
If showSecondary is True then this resource defines
how wide the column containing the primary number
is.  The default is 20 characters.
.TP
mrolo*fontList
The default font for everything in
.IR mrolo .
.TP
mrolo*addressList*fontList
Font used in address list on main screen.  This
should be a fixed width font if you want the
columns to line up.
.TP
mrolo*commentText.rows and mrolo*commentText.cols
The default size of the card text area.  You can
scroll beyond this size or resize the window,
but you might want to change this if you have a lot
of extremely large cards.
.TP
mrolo*filterText.columns
This is the size of the text field on the main screen.
.TP
mrolo*{various}.foreground and mrolo*{various}.background
Change the colors to suit your tastes; some
good values for {various} are:
nothing (default colors for application),
XmPushButton (all buttons),
XmText (all text fields),
addressList (summary screen).
.TP
mrolo*XmRowColumn*packing
If you like your buttons only as big as the text they
hold, try XmPACK_TIGHT here.  If you do that, you will
want to do the following also...
.TP
mrolo*rowColumn*resizeWidth and mrolo*rowColumn*width
Explicitly set the width of the main screen, it usually
defaults to size based on the buttons and input field
on the main screen.
.TP
mrolo*selectFilter
When set to True, is the same as using the -s option.
False is the default.
.TP
mrolo*indexElements
This string is a white-space delimited list of elements
to be made into index tabs.  The default is:
.nf
	A B C D E F G H I J K L M N O P Q R S T U V W X Y Z
.fi
.LP
This can modified to break up dense groups of entries or
to provide indexes for non-english letters.
.SH FILES
.TP 20
.B ~/.rolo
Default database.
.SH ENVIRONMENT
.TP 20
ROLODEX
Default database, overrides ~/.rolo, but not the -f option.
.SH "SEE ALSO"
.PD
.BR xr2mr (1),
.BR prolo (1),
.BR crolo (1)
.br
.ne 5
.SH BUGS
.LP
None known.  Report bugs to gregor@kafka.saic.com
.SH AUTHOR
.nf
.LP
gregg hanna (gregor@kafka.saic.com)
Science Applications International Corporation
10260 Campus Point Drive, MS C3
San Diego, California  92121
.fi
.LP
Copyright 1993 by gregg hanna.  Permission is granted
to use, modify, and distribute this program.  Basically
do anything you want with it, but if you want to use
it or any part of it to make money you must get further
permission from me.


